==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VirtualHubRouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * VirtualHub route.
 * @property addressPrefixes List of all addressPrefixes.
 * @property nextHopIpAddress NextHop ip address.
 */
public data class VirtualHubRouteArgs(
    public val addressPrefixes: Output<List<String>>? = null,
    public val nextHopIpAddress: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs =
        com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs.builder()
            .addressPrefixes(addressPrefixes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .nextHopIpAddress(nextHopIpAddress?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualHubRouteArgs].
 */
@PulumiTagMarker
public class VirtualHubRouteArgsBuilder internal constructor() {
    private var addressPrefixes: Output<List<String>>? = null

    private var nextHopIpAddress: Output<String>? = null

    /**
     * @param value List of all addressPrefixes.
     */
    @JvmName("oehmjeoylwlwocxm")
    public suspend fun addressPrefixes(`value`: Output<List<String>>) {
        this.addressPrefixes = value
    }

    @JvmName("udfekwfqolaekvgc")
    public suspend fun addressPrefixes(vararg values: Output<String>) {
        this.addressPrefixes = Output.all(values.asList())
    }

    /**
     * @param values List of all addressPrefixes.
     */
    @JvmName("dqqiipvlsgoelhge")
    public suspend fun addressPrefixes(values: List<Output<String>>) {
        this.addressPrefixes = Output.all(values)
    }

    /**
     * @param value NextHop ip address.
     */
    @JvmName("dlpqejqhllewwghg")
    public suspend fun nextHopIpAddress(`value`: Output<String>) {
        this.nextHopIpAddress = value
    }

    /**
     * @param value List of all addressPrefixes.
     */
    @JvmName("lthyrddcntmndmsy")
    public suspend fun addressPrefixes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.addressPrefixes = mapped
    }

    /**
     * @param values List of all addressPrefixes.
     */
    @JvmName("ntyvtbkvvrwtgsds")
    public suspend fun addressPrefixes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.addressPrefixes = mapped
    }

    /**
     * @param value NextHop ip address.
     */
    @JvmName("xevkhwwhulkysdwa")
    public suspend fun nextHopIpAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nextHopIpAddress = mapped
    }

    internal fun build(): VirtualHubRouteArgs = VirtualHubRouteArgs(
        addressPrefixes = addressPrefixes,
        nextHopIpAddress = nextHopIpAddress,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/VirtualHubRouteArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * VirtualHub route.
 * @property addressPrefixes List of all addressPrefixes.
 * @property nextHopIpAddress NextHop ip address.
 */
public data class VirtualHubRouteArgs(
    public val addressPrefixes: Output<List<String>>? = null,
    public val nextHopIpAddress: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs =
        com.pulumi.azurenative.network.inputs.VirtualHubRouteArgs.builder()
            .addressPrefixes(addressPrefixes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .nextHopIpAddress(nextHopIpAddress?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualHubRouteArgs].
 */
@PulumiTagMarker
public class VirtualHubRouteArgsBuilder internal constructor() {
    private var addressPrefixes: Output<List<String>>? = null

    private var nextHopIpAddress: Output<String>? = null

    /**
     * @param value List of all addressPrefixes.
     */
    @JvmName("vkuntdbhfpnperdo")
    public suspend fun addressPrefixes(`value`: Output<List<String>>) {
        this.addressPrefixes = value
    }

    @JvmName("dfvqpawnykuvqerp")
    public suspend fun addressPrefixes(vararg values: Output<String>) {
        this.addressPrefixes = Output.all(values.asList())
    }

    /**
     * @param values List of all addressPrefixes.
     */
    @JvmName("vkhropxmwfxtvirp")
    public suspend fun addressPrefixes(values: List<Output<String>>) {
        this.addressPrefixes = Output.all(values)
    }

    /**
     * @param value NextHop ip address.
     */
    @JvmName("mrchmgpenpoqcfvi")
    public suspend fun nextHopIpAddress(`value`: Output<String>) {
        this.nextHopIpAddress = value
    }

    /**
     * @param value List of all addressPrefixes.
     */
    @JvmName("pingncoppxcevyhs")
    public suspend fun addressPrefixes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.addressPrefixes = mapped
    }

    /**
     * @param values List of all addressPrefixes.
     */
    @JvmName("jqrobybjehgawwpw")
    public suspend fun addressPrefixes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.addressPrefixes = mapped
    }

    /**
     * @param value NextHop ip address.
     */
    @JvmName("bpyknxyvsmdgsqms")
    public suspend fun nextHopIpAddress(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nextHopIpAddress = mapped
    }

    internal fun build(): VirtualHubRouteArgs = VirtualHubRouteArgs(
        addressPrefixes = addressPrefixes,
        nextHopIpAddress = nextHopIpAddress,
    )
}
